<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => '.',
    'None' => 'Nenhum',
    'Edit' => 'Editar',
    'Remove' => 'Remover',
    'Yes' => 'Sim',
    'No' => 'Não',
    'cancel' => 'cancelar',
    'or' => 'ou',
    'Yellow' => 'Amarelo',
    'Blue' => 'Azul',
    'Green' => 'Verde',
    'Purple' => 'Roxo',
    'Red' => 'Vermelho',
    'Orange' => 'Laranja',
    'Grey' => 'Cinza',
    'Brown' => 'Marrom',
    'Deep Orange' => 'Laranja escuro',
    'Dark Grey' => 'Cinza escuro',
    'Pink' => 'Rosa',
    'Teal' => 'Turquesa',
    'Cyan' => 'Azul intenso',
    'Lime' => 'Verde limão',
    'Light Green' => 'Verde claro',
    'Amber' => 'Âmbar',
    'Save' => 'Salvar',
    'Login' => 'Login',
    'Official website:' => 'Site oficial:',
    'Unassigned' => 'Não Atribuída',
    'View this task' => 'Ver esta tarefa',
    'Remove user' => 'Remover usuário',
    'Do you really want to remove this user: "%s"?' => 'Você realmente deseja remover este usuário: "%s"?',
    'All users' => 'Todos os usuários',
    'Username' => 'Nome de usuário',
    'Password' => 'Senha',
    'Administrator' => 'Administrador',
    'Sign in' => 'Entrar',
    'Users' => 'Usuários',
    'Forbidden' => 'Proibido',
    'Access Forbidden' => 'Acesso negado',
    'Edit user' => 'Editar usuário',
    'Logout' => 'Sair',
    'Bad username or password' => 'Usuário ou senha inválidos',
    'Edit project' => 'Editar projeto',
    'Name' => 'Nome',
    'Projects' => 'Projetos',
    'No project' => 'Nenhum projeto',
    'Project' => 'Projeto',
    'Status' => 'Status',
    'Tasks' => 'Tarefas',
    'Board' => 'Quadro',
    'Actions' => 'Ações',
    'Inactive' => 'Inativo',
    'Active' => 'Ativo',
    'Unable to update this board.' => 'Não foi possível atualizar este quadro.',
    'Disable' => 'Desativar',
    'Enable' => 'Ativar',
    'New project' => 'Novo projeto',
    'Do you really want to remove this project: "%s"?' => 'Você realmente deseja remover este projeto: "%s"?',
    'Remove project' => 'Remover projeto',
    'Edit the board for "%s"' => 'Editar o quadro para "%s"',
    'Add a new column' => 'Adicionar uma nova coluna',
    'Title' => 'Título',
    'Assigned to %s' => 'Designado para %s',
    'Remove a column' => 'Remover uma coluna',
    'Unable to remove this column.' => 'Não foi possível remover esta coluna.',
    'Do you really want to remove this column: "%s"?' => 'Você realmente deseja remover esta coluna: "%s"?',
    'Settings' => 'Configurações',
    'Application settings' => 'Configurações da aplicação',
    'Language' => 'Idioma',
    'Webhook token:' => 'Token de webhooks:',
    'API token:' => 'Token de API:',
    'Database size:' => 'Tamanho do banco de dados:',
    'Download the database' => 'Baixar o banco de dados',
    'Optimize the database' => 'Otimizar o banco de dados',
    '(VACUUM command)' => '(Comando VACUUM)',
    '(Gzip compressed Sqlite file)' => '(Arquivo Sqlite comprimido com Gzip)',
    'Close a task' => 'Finalizar uma tarefa',
    'Column' => 'Coluna',
    'Color' => 'Cor',
    'Assignee' => 'Designação',
    'Create another task' => 'Criar outra tarefa',
    'New task' => 'Nova tarefa',
    'Open a task' => 'Abrir uma tarefa',
    'Do you really want to open this task: "%s"?' => 'Você realmente deseja abrir esta tarefa: "%s"?',
    'Back to the board' => 'Voltar ao quadro',
    'There is nobody assigned' => 'Não há ninguém designado',
    'Column on the board:' => 'Coluna no quadro:',
    'Close this task' => 'Finalizar esta tarefa',
    'Open this task' => 'Abrir esta tarefa',
    'There is no description.' => 'Não há descrição.',
    'Add a new task' => 'Adicionar uma nova tarefa',
    'The username is required' => 'O nome de usuário é obrigatório',
    'The maximum length is %d characters' => 'O tamanho máximo é %d caracteres',
    'The minimum length is %d characters' => 'O tamanho mínimo é %d caracteres',
    'The password is required' => 'A senha é obrigatória',
    'This value must be an integer' => 'O valor deve ser um número inteiro',
    'The username must be unique' => 'O nome de usuário deve ser único',
    'The user id is required' => 'O ID de usuário é obrigatório',
    'Passwords don\'t match' => 'As senhas não coincidem',
    'The confirmation is required' => 'A confirmação é obrigatória',
    'The project is required' => 'O projeto é obrigatório',
    'The id is required' => 'O ID é obrigatório',
    'The project id is required' => 'O ID do projeto é obrigatório',
    'The project name is required' => 'O nome do projeto é obrigatório',
    'The title is required' => 'O título é obrigatório',
    'Settings saved successfully.' => 'Configurações salvas com sucesso.',
    'Unable to save your settings.' => 'Não é possível salvar suas configurações.',
    'Database optimization done.' => 'Otimização do banco de dados concluída.',
    'Your project has been created successfully.' => 'Seu projeto foi criado com sucesso.',
    'Unable to create your project.' => 'Não é possível criar o seu projeto.',
    'Project updated successfully.' => 'Projeto atualizado com sucesso.',
    'Unable to update this project.' => 'Não é possível atualizar este projeto.',
    'Unable to remove this project.' => 'Não é possível remover este projeto.',
    'Project removed successfully.' => 'Projeto removido com sucesso.',
    'Project activated successfully.' => 'Projeto ativado com sucesso.',
    'Unable to activate this project.' => 'Não é possível ativar este projeto.',
    'Project disabled successfully.' => 'Projeto desativado com sucesso.',
    'Unable to disable this project.' => 'Não é possível desativar este projeto.',
    'Unable to open this task.' => 'Não é possível abrir esta tarefa.',
    'Task opened successfully.' => 'Tarefa aberta com sucesso.',
    'Unable to close this task.' => 'Não é possível finalizar esta tarefa.',
    'Task closed successfully.' => 'Tarefa finalizada com sucesso.',
    'Unable to update your task.' => 'Não é possível atualizar a sua tarefa.',
    'Task updated successfully.' => 'Tarefa atualizada com sucesso.',
    'Unable to create your task.' => 'Não é possível criar a sua tarefa.',
    'Task created successfully.' => 'Tarefa criada com sucesso.',
    'User created successfully.' => 'Usuário criado com sucesso.',
    'Unable to create your user.' => 'Não é possível criar o seu usuário.',
    'User updated successfully.' => 'Usuário atualizado com sucesso.',
    'User removed successfully.' => 'Usuário removido com sucesso.',
    'Unable to remove this user.' => 'Não é possível remover este usuário.',
    'Board updated successfully.' => 'Quadro atualizado com sucesso.',
    'Ready' => 'A fazer',
    'Backlog' => 'Backlog',
    'Work in progress' => 'Em andamento',
    'Done' => 'Feito',
    'Application version:' => 'Versão da aplicação:',
    'Id' => 'Id',
    'Public link' => 'Link público',
    'Timezone' => 'Fuso horário',
    'Sorry, I didn\'t find this information in my database!' => 'Desculpe, não encontrei esta informação no meu banco de dados!',
    'Page not found' => 'Página não encontrada',
    'Complexity' => 'Complexidade',
    'Task limit' => 'Limite de tarefas',
    'Task count' => 'Número de tarefas',
    'User' => 'Usuário',
    'Comments' => 'Comentários',
    'Comment is required' => 'Comentário é obrigatório',
    'Comment added successfully.' => 'Comentário adicionado com sucesso.',
    'Unable to create your comment.' => 'Não é possível criar o seu comentário.',
    'Due Date' => 'Data fim estimada',
    'Invalid date' => 'Data inválida',
    'Automatic actions' => 'Ações automáticas',
    'Your automatic action has been created successfully.' => 'Sua ação automática foi criada com sucesso.',
    'Unable to create your automatic action.' => 'Não é possível criar sua ação automática.',
    'Remove an action' => 'Remover uma ação',
    'Unable to remove this action.' => 'Não é possível remover esta ação.',
    'Action removed successfully.' => 'Ação removida com sucesso.',
    'Automatic actions for the project "%s"' => 'Ações automáticas para o projeto "%s"',
    'Add an action' => 'Adicionar Ação',
    'Event name' => 'Nome do evento',
    'Action' => 'Ação',
    'Event' => 'Evento',
    'When the selected event occurs execute the corresponding action.' => 'Quando o evento selecionado ocorrer execute a ação correspondente.',
    'Next step' => 'Próximo passo',
    'Define action parameters' => 'Definir parâmetros da ação',
    'Do you really want to remove this action: "%s"?' => 'Você realmente deseja remover esta ação: "%s"?',
    'Remove an automatic action' => 'Remover uma ação automática',
    'Assign the task to a specific user' => 'Atribuir a tarefa para um usuário específico',
    'Assign the task to the person who does the action' => 'Atribuir a tarefa para a pessoa que executa a ação',
    'Duplicate the task to another project' => 'Duplicar a tarefa para outro projeto',
    'Move a task to another column' => 'Mover a tarefa para outra coluna',
    'Task modification' => 'Modificação de tarefa',
    'Task creation' => 'Criação de tarefa',
    'Closing a task' => 'Finalizando uma tarefa',
    'Assign a color to a specific user' => 'Atribuir uma cor para um usuário específico',
    'Position' => 'Posição',
    'Duplicate to project' => 'Duplicar para outro projeto',
    'Duplicate' => 'Duplicar',
    'Link' => 'Link',
    'Comment updated successfully.' => 'Comentário atualizado com sucesso.',
    'Unable to update your comment.' => 'Não é possível atualizar o seu comentário.',
    'Remove a comment' => 'Remover um comentário',
    'Comment removed successfully.' => 'Comentário removido com sucesso.',
    'Unable to remove this comment.' => 'Não é possível remover este comentário.',
    'Do you really want to remove this comment?' => 'Você realmente deseja remover este comentário?',
    'Current password for the user "%s"' => 'Senha atual para o usuário "%s"',
    'The current password is required' => 'A senha atual é obrigatória',
    'Wrong password' => 'Senha incorreta',
    'Unknown' => 'Desconhecido',
    'Last logins' => 'Últimos logins',
    'Login date' => 'Data de login',
    'Authentication method' => 'Método de autenticação',
    'IP address' => 'Endereço IP',
    'User agent' => 'User Agent',
    'Persistent connections' => 'Conexões persistentes',
    'No session.' => 'Nenhuma sessão.',
    'Expiration date' => 'Data de expiração',
    'Remember Me' => 'Lembre-se de mim',
    'Creation date' => 'Data de criação',
    'Everybody' => 'Todos',
    'Open' => 'Abrir',
    'Closed' => 'Finalizado',
    'Search' => 'Pesquisar',
    'Nothing found.' => 'Nada foi encontrado.',
    'Due date' => 'Data fim estimada',
    'Description' => 'Descrição',
    '%d comments' => '%d comentários',
    '%d comment' => '%d comentário',
    'Email address invalid' => 'Endereço de e-mail inválido',
    'Your external account is not linked anymore to your profile.' => 'Sua conta externa não está mais ligada ao seu perfil.',
    'Unable to unlink your external account.' => 'Impossível de remover a sua conta externa.',
    'External authentication failed' => 'Autenticação externa falhou',
    'Your external account is linked to your profile successfully.' => 'Sua conta externa está agora ligada ao seu perfil.',
    'Email' => 'E-mail',
    'Task removed successfully.' => 'Tarefa removida com sucesso.',
    'Unable to remove this task.' => 'Não foi possível remover esta tarefa.',
    'Remove a task' => 'Remover uma tarefa',
    'Do you really want to remove this task: "%s"?' => 'Você realmente deseja remover esta tarefa: "%s"?',
    'Assign automatically a color based on a category' => 'Atribuir automaticamente uma cor com base em uma categoria',
    'Assign automatically a category based on a color' => 'Atribuir automaticamente uma categoria com base em uma cor',
    'Task creation or modification' => 'Criação ou modificação de tarefa',
    'Category' => 'Categoria',
    'Category:' => 'Categoria:',
    'Categories' => 'Categorias',
    'Your category has been created successfully.' => 'Sua categoria foi criada com sucesso.',
    'This category has been updated successfully.' => 'A sua categoria foi atualizada com sucesso.',
    'Unable to update this category.' => 'Não foi possível atualizar a sua categoria.',
    'Remove a category' => 'Remover uma categoria',
    'Category removed successfully.' => 'Categoria removida com sucesso.',
    'Unable to remove this category.' => 'Não foi possível remover esta categoria.',
    'Category modification for the project "%s"' => 'Modificação de categoria para o projeto "%s"',
    'Category Name' => 'Nome da categoria',
    'Add a new category' => 'Adicionar uma nova categoria',
    'Do you really want to remove this category: "%s"?' => 'Você realmente deseja remover esta categoria: "%s"?',
    'All categories' => 'Todas as categorias',
    'No category' => 'Nenhuma categoria',
    'The name is required' => 'O nome é obrigatório',
    'Remove a file' => 'Remover um arquivo',
    'Unable to remove this file.' => 'Não foi possível remover este arquivo.',
    'File removed successfully.' => 'Arquivo removido com sucesso.',
    'Attach a document' => 'Anexar um documento',
    'Do you really want to remove this file: "%s"?' => 'Você realmente deseja remover este arquivo: "%s"?',
    'Attachments' => 'Anexos',
    'Edit the task' => 'Editar a tarefa',
    'Add a comment' => 'Adicionar um comentário',
    'Edit a comment' => 'Editar um comentário',
    'Summary' => 'Resumo',
    'Time tracking' => 'Rastreamento de tempo',
    'Estimate:' => 'Estimado:',
    'Spent:' => 'Gasto:',
    'Do you really want to remove this sub-task?' => 'Você realmente deseja remover esta subtarefa?',
    'Remaining:' => 'Restante:',
    'hours' => 'horas',
    'estimated' => 'estimado',
    'Sub-Tasks' => 'Subtarefas',
    'Add a sub-task' => 'Adicionar uma subtarefa',
    'Original estimate' => 'Estimativa original',
    'Create another sub-task' => 'Criar uma outra subtarefa',
    'Time spent' => 'Tempo gasto',
    'Edit a sub-task' => 'Editar uma subtarefa',
    'Remove a sub-task' => 'Remover uma subtarefa',
    'The time must be a numeric value' => 'O tempo deve ser um valor numérico',
    'Todo' => 'A fazer',
    'In progress' => 'Em andamento',
    'Sub-task removed successfully.' => 'Subtarefa removida com sucesso.',
    'Unable to remove this sub-task.' => 'Não foi possível remover esta subtarefa.',
    'Sub-task updated successfully.' => 'Subtarefa atualizada com sucesso.',
    'Unable to update your sub-task.' => 'Não foi possível atualizar a sua subtarefa.',
    'Unable to create your sub-task.' => 'Não é possível criar a sua subtarefa.',
    'Maximum size: ' => 'Tamanho máximo: ',
    'Display another project' => 'Exibir outro projeto',
    'Created by %s' => 'Criado por %s',
    'Tasks Export' => 'Exportar Tarefas',
    'Start Date' => 'Data inicial',
    'Execute' => 'Executar',
    'Task Id' => 'ID da Tarefa',
    'Creator' => 'Criado por',
    'Modification date' => 'Data da modificação',
    'Completion date' => 'Data da finalização',
    'Clone' => 'Clonar',
    'Project cloned successfully.' => 'Projeto clonado com sucesso.',
    'Unable to clone this project.' => 'Não foi possível clonar este projeto.',
    'Enable email notifications' => 'Habilitar notificações por e-mail',
    'Task position:' => 'Posição da tarefa:',
    'The task #%d has been opened.' => 'A tarefa #%d foi aberta.',
    'The task #%d has been closed.' => 'A tarefa #%d foi finalizada.',
    'Sub-task updated' => 'Subtarefa atualizada',
    'Title:' => 'Título:',
    'Status:' => 'Status:',
    'Assignee:' => 'Designado:',
    'Time tracking:' => 'Controle de tempo:',
    'New sub-task' => 'Nova subtarefa',
    'New attachment added "%s"' => 'Novo anexo adicionado "%s"',
    'New comment posted by %s' => 'Novo comentário postado por %s',
    'New comment' => 'Novo comentário',
    'Comment updated' => 'Comentário atualizado',
    'New subtask' => 'Nova subtarefa',
    'I only want to receive notifications for these projects:' => 'Quero receber notificações apenas destes projetos:',
    'view the task on Kanboard' => 'ver a tarefa no Kanboard',
    'Public access' => 'Acesso público',
    'Disable public access' => 'Desabilitar o acesso público',
    'Enable public access' => 'Habilitar o acesso público',
    'Public access disabled' => 'Acesso público desabilitado',
    'Move the task to another project' => 'Mover a tarefa para outro projeto',
    'Move to project' => 'Mover para outro projeto',
    'Do you really want to duplicate this task?' => 'Você realmente deseja duplicar esta tarefa?',
    'Duplicate a task' => 'Duplicar uma tarefa',
    'External accounts' => 'Contas externas',
    'Account type' => 'Tipo de conta',
    'Local' => 'Local',
    'Remote' => 'Remoto',
    'Enabled' => 'Habilitado',
    'Disabled' => 'Desabilitado',
    'Login:' => 'Usuário:',
    'Full Name:' => 'Nome:',
    'Email:' => 'E-mail:',
    'Notifications:' => 'Notificações:',
    'Notifications' => 'Notificações',
    'Account type:' => 'Tipo de conta:',
    'Edit profile' => 'Editar perfil',
    'Change password' => 'Alterar senha',
    'Password modification' => 'Alteração de senha',
    'External authentications' => 'Autenticação externa',
    'Never connected.' => 'Nunca conectado.',
    'No external authentication enabled.' => 'Nenhuma autenticação externa habilitada.',
    'Password modified successfully.' => 'Senha alterada com sucesso.',
    'Unable to change the password.' => 'Não foi possível alterar a senha.',
    'Change category' => 'Mudar categoria',
    '%s updated the task %s' => '%s atualizou a tarefa %s',
    '%s opened the task %s' => '%s abriu a tarefa %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s moveu a tarefa %s para a posição #%d na coluna "%s"',
    '%s moved the task %s to the column "%s"' => '%s moveu a tarefa %s para a coluna "%s"',
    '%s created the task %s' => '%s criou a tarefa %s',
    '%s closed the task %s' => '%s finalizou a tarefa %s',
    '%s created a subtask for the task %s' => '%s criou uma subtarefa para a tarefa %s',
    '%s updated a subtask for the task %s' => '%s atualizou uma subtarefa da tarefa %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Designado para %s com tempo estimado de %s/%sh',
    'Not assigned, estimate of %sh' => 'Não designado, estimado em %sh',
    '%s updated a comment on the task %s' => '%s atualizou o comentário na tarefa %s',
    '%s commented the task %s' => '%s comentou a tarefa %s',
    '%s\'s activity' => 'Atividades de %s',
    'RSS feed' => 'Feed RSS',
    '%s updated a comment on the task #%d' => '%s atualizou um comentário sobre a tarefa #%d',
    '%s commented on the task #%d' => '%s comentou sobre a tarefa #%d',
    '%s updated a subtask for the task #%d' => '%s atualizou uma subtarefa para a tarefa #%d',
    '%s created a subtask for the task #%d' => '%s criou uma subtarefa para a tarefa #%d',
    '%s updated the task #%d' => '%s atualizou a tarefa #%d',
    '%s created the task #%d' => '%s criou a tarefa #%d',
    '%s closed the task #%d' => '%s finalizou a tarefa #%d',
    '%s opened the task #%d' => '%s abriu a tarefa #%d',
    'Activity' => 'Atividade',
    'Default values are "%s"' => 'Os valores padrão são "%s"',
    'Default columns for new projects (Comma-separated)' => 'Colunas padrão para novos projetos (Separado por vírgula)',
    'Task assignee change' => 'Mudar designação da tarefa',
    '%s changed the assignee of the task #%d to %s' => '%s mudou a designação da tarefa #%d para %s',
    '%s changed the assignee of the task %s to %s' => '%s mudou a designação da tarefa %s para %s',
    'New password for the user "%s"' => 'Nova senha para o usuário "%s"',
    'Choose an event' => 'Escolher um evento',
    'Create a task from an external provider' => 'Criar uma tarefa por meio de um serviço externo',
    'Change the assignee based on an external username' => 'Alterar designação com base em um usuário externo',
    'Change the category based on an external label' => 'Alterar categoria com base em um rótulo externo',
    'Reference' => 'Referência',
    'Label' => 'Rótulo',
    'Database' => 'Banco de dados',
    'About' => 'Sobre',
    'Database driver:' => 'Driver do banco de dados:',
    'Board settings' => 'Configurações do quadro',
    'Webhook settings' => 'Configurações do Webhook',
    'Reset token' => 'Resetar token',
    'API endpoint:' => 'API endpoint:',
    'Refresh interval for personal board' => 'Intervalo de atualização para um quadro privado',
    'Refresh interval for public board' => 'Intervalo de atualização para um quadro público',
    'Task highlight period' => 'Período de Tarefa em destaque',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Período (em segundos) para considerar que uma tarefa foi modificada recentemente (0 para desativar, 2 dias por padrão)',
    'Frequency in second (60 seconds by default)' => 'Frequência em segundos (60 segundos por padrão)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frequência em segundos (0 para desativar este recurso, 10 segundos por padrão)',
    'Application URL' => 'URL da Aplicação',
    'Token regenerated.' => 'Novo token gerado.',
    'Date format' => 'Formato de data',
    'ISO format is always accepted, example: "%s" and "%s"' => 'O formato ISO é sempre aceito, exemplo: "%s" e "%s"',
    'New personal project' => 'Novo projeto pessoal',
    'This project is personal' => 'Este projeto é pessoal',
    'Add' => 'Adicionar',
    'Start date' => 'Data de início',
    'Time estimated' => 'Tempo estimado',
    'There is nothing assigned to you.' => 'Não há nada designado a você.',
    'My tasks' => 'Minhas tarefas',
    'Activity stream' => 'Atividades Recentes',
    'Dashboard' => 'Painel de Controle',
    'Confirmation' => 'Confirmação',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Criar um comentário por meio de um serviço externo',
    'Project management' => 'Gerenciamento de projetos',
    'Columns' => 'Colunas',
    'Task' => 'Tarefas',
    'Percentage' => 'Porcentagem',
    'Number of tasks' => 'Número de tarefas',
    'Task distribution' => 'Distribuição de tarefas',
    'Analytics' => 'Estatísticas',
    'Subtask' => 'Subtarefa',
    'User repartition' => 'Redistribuição de usuário',
    'Clone this project' => 'Clonar este projeto',
    'Column removed successfully.' => 'Coluna removida com sucesso.',
    'Not enough data to show the graph.' => 'Não há dados suficientes para mostrar o gráfico.',
    'Previous' => 'Anterior',
    'The id must be an integer' => 'O ID deve ser um número inteiro',
    'The project id must be an integer' => 'O ID do projeto deve ser um inteiro',
    'The status must be an integer' => 'O status deve ser um número inteiro',
    'The subtask id is required' => 'O ID da subtarefa é obrigatório',
    'The subtask id must be an integer' => 'O ID da subtarefa deve ser um número inteiro',
    'The task id is required' => 'O ID da tarefa é obrigatório',
    'The task id must be an integer' => 'O ID da tarefa deve ser um número inteiro',
    'The user id must be an integer' => 'O ID do usuário deve ser um número inteiro',
    'This value is required' => 'Este valor é obrigatório',
    'This value must be numeric' => 'Este valor deve ser numérico',
    'Unable to create this task.' => 'Não foi possível criar esta tarefa.',
    'Cumulative flow diagram' => 'Fluxograma cumulativo',
    'Daily project summary' => 'Resumo diário do projeto',
    'Daily project summary export' => 'Exportação diária do resumo do projeto',
    'Exports' => 'Exportar',
    'This export contains the number of tasks per column grouped per day.' => 'Esta exportação contém o número de tarefas por coluna agrupada por dia.',
    'Active swimlanes' => 'Raias ativas',
    'Add a new swimlane' => 'Adicionar uma nova raia',
    'Default swimlane' => 'Raia padrão',
    'Do you really want to remove this swimlane: "%s"?' => 'Você realmente deseja remover esta raia: "%s"?',
    'Inactive swimlanes' => 'Raias inativas',
    'Remove a swimlane' => 'Remover uma raia',
    'Swimlane modification for the project "%s"' => 'Modificação de raia para o projeto "%s"',
    'Swimlane removed successfully.' => 'Raia removida com sucesso.',
    'Swimlanes' => 'Raias',
    'Swimlane updated successfully.' => 'Raia atualizada com sucesso.',
    'Unable to remove this swimlane.' => 'Não foi possível remover esta raia.',
    'Unable to update this swimlane.' => 'Não foi possível atualizar esta raia.',
    'Your swimlane has been created successfully.' => 'Sua raia foi criada com sucesso.',
    'Example: "Bug, Feature Request, Improvement"' => 'Exemplo: "Bug, Solicitação de Recurso, Melhoria"',
    'Default categories for new projects (Comma-separated)' => 'Categorias padrões para novos projetos (separadas por vírgula)',
    'Integrations' => 'Integrações',
    'Integration with third-party services' => 'Integração com serviços de terceiros',
    'Subtask Id' => 'ID da subtarefa',
    'Subtasks' => 'Subtarefas',
    'Subtasks Export' => 'Exportar subtarefas',
    'Task Title' => 'Título da Tarefa',
    'Untitled' => 'Sem título',
    'Application default' => 'Padrão da aplicação',
    'Language:' => 'Idioma',
    'Timezone:' => 'Fuso horário',
    'All columns' => 'Todas as colunas',
    'Next' => 'Próximo',
    '#%d' => '#%d',
    'All swimlanes' => 'Todas as raias',
    'All colors' => 'Todas as cores',
    'Moved to column %s' => 'Movido para a coluna %s',
    'User dashboard' => 'Painel de Controle do usuário',
    'Allow only one subtask in progress at the same time for a user' => 'Permitir apenas uma subtarefa em andamento ao mesmo tempo para um usuário',
    'Edit column "%s"' => 'Editar a coluna "%s"',
    'Select the new status of the subtask: "%s"' => 'Selecionar um novo status para a subtarefa: "%s"',
    'Subtask timesheet' => 'Gestão de tempo das subtarefas',
    'There is nothing to show.' => 'Não há nada para mostrar.',
    'Time Tracking' => 'Gestão de tempo',
    'You already have one subtask in progress' => 'Você já tem um subtarefa em andamento',
    'Which parts of the project do you want to duplicate?' => 'Quais partes do projeto você deseja duplicar?',
    'Disallow login form' => 'Proibir o formulário de login',
    'Start' => 'Início',
    'End' => 'Fim',
    'Task age in days' => 'Idade da tarefa em dias',
    'Days in this column' => 'Dias nesta coluna',
    '%dd' => '%dd',
    'Add a new link' => 'Adicionar uma nova associação',
    'Do you really want to remove this link: "%s"?' => 'Você realmente deseja remover esta associação: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Você realmente deseja remover esta associação com a tarefa #%d?',
    'Field required' => 'Campo requerido',
    'Link added successfully.' => 'Associação criada com sucesso.',
    'Link updated successfully.' => 'Associação atualizada com sucesso.',
    'Link removed successfully.' => 'Associação removida com sucesso.',
    'Link labels' => 'Rótulos das associações',
    'Link modification' => 'Modificação de uma associação',
    'Opposite label' => 'Nome do rótulo oposto',
    'Remove a link' => 'Remover uma associação',
    'The labels must be different' => 'Os rótulos devem ser diferentes',
    'There is no link.' => 'Não há nenhuma associação.',
    'This label must be unique' => 'Este rótulo deve ser único',
    'Unable to create your link.' => 'Impossível de adicionar sua associação.',
    'Unable to update your link.' => 'Impossível de atualizar sua associação.',
    'Unable to remove this link.' => 'Impossível de remover sua associação.',
    'relates to' => 'é associada com',
    'blocks' => 'bloqueia',
    'is blocked by' => 'está bloqueada por',
    'duplicates' => 'duplica',
    'is duplicated by' => 'é duplicada por',
    'is a child of' => 'é filha de',
    'is a parent of' => 'é pai de',
    'targets milestone' => 'marcos alvos',
    'is a milestone of' => 'é um marco de',
    'fixes' => 'corrige',
    'is fixed by' => 'foi corrigida por',
    'This task' => 'Esta tarefa',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Expandir tarefas',
    'Collapse tasks' => 'Contrair tarefas',
    'Expand/collapse tasks' => 'Expandir/Contrair tarefas',
    'Close dialog box' => 'Fechar a caixa de diálogo',
    'Submit a form' => 'Envia o formulário',
    'Board view' => 'Visão do quadro',
    'Keyboard shortcuts' => 'Atalhos de teclado',
    'Open board switcher' => 'Abrir opções de quadros',
    'Application' => 'Aplicação',
    'Compact view' => 'Vista reduzida',
    'Horizontal scrolling' => 'Rolagem horizontal',
    'Compact/wide view' => 'Alternar entre a vista compacta e ampliada',
    'Currency' => 'Moeda',
    'Personal project' => 'Projeto pessoal',
    'AUD - Australian Dollar' => 'AUD - Dólar australiano',
    'CAD - Canadian Dollar' => 'CAD - Dólar canadense',
    'CHF - Swiss Francs' => 'CHF - Francos Suíços',
    'Custom Stylesheet' => 'Folha de estilo personalizado',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Libra esterlina',
    'INR - Indian Rupee' => 'INR - Rúpia indiana',
    'JPY - Japanese Yen' => 'JPY - Iene japonês',
    'NZD - New Zealand Dollar' => 'NZD - Dólar neozelandês',
    'PEN - Peruvian Sol' => 'PEN - Sol peruano',
    'RSD - Serbian dinar' => 'RSD - Dinar sérvio',
    'CNY - Chinese Yuan' => 'CNY - Yuan chinês',
    'USD - US Dollar' => 'USD - Dólar norte-americano',
    'VES - Venezuelan Bolívar' => 'VES - Bolívar venezuelano',
    'Destination column' => 'Coluna de destino',
    'Move the task to another column when assigned to a user' => 'Mover a tarefa para uma outra coluna quando esta está atribuída a um usuário',
    'Move the task to another column when assignee is cleared' => 'Mover a tarefa para uma outra coluna quando esta não está atribuída',
    'Source column' => 'Coluna de origem',
    'Transitions' => 'Transições',
    'Executer' => 'Executor(a)',
    'Time spent in the column' => 'Tempo gasto na coluna',
    'Task transitions' => 'Transições das tarefas',
    'Task transitions export' => 'Exportação das transições das tarefas',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Este relatório contém todos os movimentos de coluna para cada tarefa com a data, o usuário e o tempo gasto para cada transição.',
    'Currency rates' => 'Taxas de câmbio das moedas estrangeiras',
    'Rate' => 'Taxa',
    'Change reference currency' => 'Mudar a moeda de referência',
    'Reference currency' => 'Moeda de Referência',
    'The currency rate has been added successfully.' => 'A taxa de câmbio foi adicionada com sucesso.',
    'Unable to add this currency rate.' => 'Impossível de adicionar essa taxa de câmbio.',
    'Webhook URL' => 'URL do webhook',
    '%s removed the assignee of the task %s' => '%s removeu a pessoa designada para a tarefa %s',
    'Information' => 'Informações',
    'Check two factor authentication code' => 'Verifique o código de autenticação em duas etapas',
    'The two factor authentication code is not valid.' => 'O código de autenticação em duas etapas não é válido.',
    'The two factor authentication code is valid.' => 'O código de autenticação em duas etapas é válido.',
    'Code' => 'Código',
    'Two factor authentication' => 'Autenticação em duas etapas',
    'This QR code contains the key URI: ' => 'Este Código QR contém a chave URI:',
    'Check my code' => 'Verifique o meu código',
    'Secret key: ' => 'Chave secreta:',
    'Test your device' => 'Teste o seu dispositivo',
    'Assign a color when the task is moved to a specific column' => 'Atribuir uma cor quando a tarefa for movida para uma coluna específica',
    '%s via Kanboard' => '%s via Kanboard',
    'Burndown chart' => 'Gráfico de Burndown',
    'This chart show the task complexity over the time (Work Remaining).' => 'Este gráfico mostra a complexidade da tarefa ao longo do tempo (Trabalho Restante).',
    'Screenshot taken %s' => 'Captura de tela tirada em %s',
    'Add a screenshot' => 'Adicionar uma captura de tela',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Tire uma captura de tela e pressione CTRL+V ou ⌘+V para colar aqui.',
    'Screenshot uploaded successfully.' => 'Captura de tela enviada com sucesso.',
    'SEK - Swedish Krona' => 'SEK - Coroa sueca',
    'Identifier' => 'Identificador',
    'Disable two factor authentication' => 'Desativar autenticação em duas etapas',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Você realmente deseja desativar a autenticação em duas etapas para este usuário: "%s"?',
    'Edit link' => 'Editar um link',
    'Start to type task title...' => 'Digite o título da tarefa...',
    'A task cannot be linked to itself' => 'Uma tarefa não pode ser vinculada a si própria',
    'The exact same link already exists' => 'Um link idêntico já existe',
    'Recurrent task is scheduled to be generated' => 'A tarefa recorrente está programada para ser criada',
    'Score' => 'Complexidade',
    'The identifier must be unique' => 'O identificador deve ser único',
    'This linked task id doesn\'t exists' => 'O identificador da tarefa associada não existe',
    'This value must be alphanumeric' => 'Este valor deve ser alfanumérico',
    'Edit recurrence' => 'Modificar a recorrência',
    'Generate recurrent task' => 'Gerar uma tarefa recorrente',
    'Trigger to generate recurrent task' => 'Trigger para gerar tarefa recorrente',
    'Factor to calculate new due date' => 'Fator para o cálculo da nova data fim estimada',
    'Timeframe to calculate new due date' => 'Escala de tempo para o cálculo da nova data fim estimada',
    'Base date to calculate new due date' => 'Data a ser utilizada para calcular a nova data fim estimada',
    'Action date' => 'Data da ação',
    'Base date to calculate new due date: ' => 'Data a ser utilizada para calcular a nova data fim estimada: ',
    'This task has created this child task: ' => 'Esta tarefa criou a tarefa filha: ',
    'Day(s)' => 'Dia(s)',
    'Existing due date' => 'data fim estimada existente',
    'Factor to calculate new due date: ' => 'Fator para calcular a nova data fim estimada: ',
    'Month(s)' => 'Mês(es)',
    'This task has been created by: ' => 'Esta tarefa foi criada por: ',
    'Recurrent task has been generated:' => 'A tarefa recorrente foi gerada:',
    'Timeframe to calculate new due date: ' => 'Escala de tempo para o cálculo da nova data fim estimada: ',
    'Trigger to generate recurrent task: ' => 'Trigger para gerar tarefa recorrente: ',
    'When task is closed' => 'Quando a tarefa é finalizada',
    'When task is moved from first column' => 'Quando a tarefa é movida fora da primeira coluna',
    'When task is moved to last column' => 'Quando a tarefa é movida para a última coluna',
    'Year(s)' => 'Ano(s)',
    'Project settings' => 'Configurações dos projetos',
    'Automatically update the start date' => 'Atualizar automaticamente a data de início',
    'iCal feed' => 'Subscrição iCal',
    'Preferences' => 'Preferências',
    'Security' => 'Segurança',
    'Two factor authentication disabled' => 'Autenticação em duas etapas desativada',
    'Two factor authentication enabled' => 'Autenticação em duas etapas ativada',
    'Unable to update this user.' => 'Impossível de atualizar esse usuário.',
    'There is no user management for personal projects.' => 'Não há gerenciamento de usuários para projetos pessoais.',
    'User that will receive the email' => 'O usuário que vai receber o e-mail',
    'Email subject' => 'Assunto do e-mail',
    'Date' => 'Data',
    'Add a comment log when moving the task between columns' => 'Adicionar um comentário de log quando uma tarefa é movida para uma outra coluna',
    'Move the task to another column when the category is changed' => 'Mover uma tarefa para outra coluna quando a categoria mudou',
    'Send a task by email to someone' => 'Enviar uma tarefa por e-mail a alguém',
    'Reopen a task' => 'Reabrir uma tarefa',
    'Notification' => 'Notificação',
    '%s moved the task #%d to the first swimlane' => '%s moveu a tarefa #%d para a primeira raia',
    'Swimlane' => 'Raia',
    '%s moved the task %s to the first swimlane' => '%s moveu a tarefa %s para a primeira raia',
    '%s moved the task %s to the swimlane "%s"' => '%s moveu a tarefa %s para a raia "%s"',
    'This report contains all subtasks information for the given date range.' => 'Este relatório contém informações de todas as subtarefas para o período selecionado.',
    'This report contains all tasks information for the given date range.' => 'Este relatório contém informações de todas as tarefas para o período selecionado.',
    'Project activities for %s' => 'Atividade do projeto "%s"',
    'view the board on Kanboard' => 'ver o quadro no Kanboard',
    'The task has been moved to the first swimlane' => 'A tarefa foi movida para a primeira raia',
    'The task has been moved to another swimlane:' => 'A tarefa foi movida para outra raia:',
    'New title: %s' => 'Novo título: %s',
    'The task is not assigned anymore' => 'Agora a tarefa não está mais atribuída',
    'New assignee: %s' => 'Novo designado: %s',
    'There is no category now' => 'Agora não tem mais categoria',
    'New category: %s' => 'Nova categoria: %s',
    'New color: %s' => 'Nova cor: %s',
    'New complexity: %d' => 'Nova complexidade: %d',
    'The due date has been removed' => 'A data fim estimada foi retirada',
    'There is no description anymore' => 'Agora não tem mais descrição',
    'Recurrence settings has been modified' => 'As configurações da recorrência foram modificadas',
    'Time spent changed: %sh' => 'O tempo despendido foi mudado: %sh',
    'Time estimated changed: %sh' => 'O tempo estimado foi mudado/ %sh',
    'The field "%s" has been updated' => 'O campo "%s" foi atualizada',
    'The description has been modified:' => 'A descrição foi modificada',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Você realmente deseja finalizar a tarefa "%s" e todas as suas subtarefas?',
    'I want to receive notifications for:' => 'Eu quero receber as notificações para:',
    'All tasks' => 'Todas as tarefas',
    'Only for tasks assigned to me' => 'Somente as tarefas atribuídas a mim',
    'Only for tasks created by me' => 'Apenas as tarefas que eu criei',
    'Only for tasks created by me and tasks assigned to me' => 'Apenas as tarefas que eu criei e aquelas atribuídas a mim',
    '%%Y-%%m-%%d' => '%%d/%%m/%%Y',
    'Total for all columns' => 'Total para todas as colunas',
    'You need at least 2 days of data to show the chart.' => 'Você precisa de pelo menos 2 dias de dados para visualizar o gráfico.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Parar temporizador',
    'Start timer' => 'Iniciar temporizador',
    'My activity stream' => 'Meu feed de atividades',
    'Search tasks' => 'Pesquisar tarefas',
    'Reset filters' => 'Redefinir os filtros',
    'My tasks due tomorrow' => 'Minhas tarefas que expirarão amanhã',
    'Tasks due today' => 'Tarefas que expiram hoje',
    'Tasks due tomorrow' => 'Tarefas que expirarão amanhã',
    'Tasks due yesterday' => 'Tarefas que expiraram ontem',
    'Closed tasks' => 'Tarefas finalizadas',
    'Open tasks' => 'Tarefas abertas',
    'Not assigned' => 'Não designada',
    'View advanced search syntax' => 'Ver a sintaxe para pesquisa avançada',
    'Overview' => 'Visão global',
    'Board/Calendar/List view' => 'Quadro/Calendário/Lista',
    'Switch to the board view' => 'Mudar para a visão de quadro',
    'Switch to the list view' => 'Mudar par o modo Lista',
    'Go to the search/filter box' => 'Ir para o campo de filtro/pesquisa',
    'There is no activity yet.' => 'Não há nenhuma atividade ainda.',
    'No tasks found.' => 'Nenhuma tarefa encontrada.',
    'Keyboard shortcut: "%s"' => 'Tecla de atalho: "%s"',
    'List' => 'Lista',
    'Filter' => 'Filtro',
    'Advanced search' => 'Pesquisa avançada',
    'Example of query: ' => 'Exemplo de consulta: ',
    'Search by project: ' => 'Pesquisar por projeto: ',
    'Search by column: ' => 'Pesquisar por coluna: ',
    'Search by assignee: ' => 'Pesquisar por designado: ',
    'Search by color: ' => 'Pesquisar por cor: ',
    'Search by category: ' => 'Pesquisar por categoria: ',
    'Search by description: ' => 'Pesquisar por descrição: ',
    'Search by due date: ' => 'Pesquisar por data fim estimada: ',
    'Average time spent in each column' => 'Tempo médio gasto em cada coluna',
    'Average time spent' => 'Tempo médio gasto',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Este gráfico mostra o tempo médio gasto em cada coluna para as %d últimas tarefas.',
    'Average Lead and Cycle time' => 'Tempo médio do tempo de condução e tempo de ciclo',
    'Average lead time: ' => 'Tempo de condução médio: ',
    'Average cycle time: ' => 'Tempo de ciclo médio: ',
    'Cycle Time' => 'Tempo de ciclo',
    'Lead Time' => 'Tempo de condução',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Este gráfico mostra o tempo médio do tempo de condução e tempo de ciclo das últimas %d tarefas.',
    'Average time into each column' => 'Tempo médio de cada coluna',
    'Lead and cycle time' => 'Tempo de condução e tempo de ciclo',
    'Lead time: ' => 'Tempo de condução: ',
    'Cycle time: ' => 'Tempo de ciclo: ',
    'Time spent in each column' => 'Tempo gasto em cada coluna',
    'The lead time is the duration between the task creation and the completion.' => 'O tempo de condução é o tempo gasto entre a criação da tarefa e a sua conclusão.',
    'The cycle time is the duration between the start date and the completion.' => 'O Tempo de ciclo é o tempo gasto entre a data de início e a sua conclusão.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Se a tarefa não está finalizada, a hora atual é usada no lugar da data de conclusão.',
    'Set the start date automatically' => 'Definir automaticamente a data de início',
    'Edit Authentication' => 'Modificar a autenticação',
    'Remote user' => 'Usuário remoto',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Os usuários remotos não conservam as suas senhas no banco de dados Kanboard, exemplos: contas LDAP, Github ou Google.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Se você marcar "Impedir o formulário de autenticação", os identificadores entrados no formulário de login serão ignorado.',
    'Default task color' => 'Cor padrão para as tarefas',
    'This feature does not work with all browsers.' => 'Esta funcionalidade não é compatível com todos os navegadores.',
    'There is no destination project available.' => 'Não há nenhum projeto de destino disponível.',
    'Trigger automatically subtask time tracking' => 'Ativar automaticamente o monitoramento do tempo para as subtarefas',
    'Include closed tasks in the cumulative flow diagram' => 'Incluir as tarefas finalizadas no diagrama de fluxo acumulado',
    'Current swimlane: %s' => 'Raia atual: %s',
    'Current column: %s' => 'Coluna atual: %s',
    'Current category: %s' => 'Categoria atual: %s',
    'no category' => 'nenhuma categoria',
    'Current assignee: %s' => 'Designação atual: %s',
    'not assigned' => 'não designado',
    'Author:' => 'Autor:',
    'contributors' => 'contribuidores',
    'License:' => 'Licença:',
    'License' => 'Licença',
    'Enter the text below' => 'Digite o texto abaixo',
    'Start date:' => 'Data de início:',
    'Due date:' => 'Data fim estimada:',
    'People who are project managers' => 'Pessoas que são gerente de projeto',
    'People who are project members' => 'Pessoas que são membro de projeto',
    'NOK - Norwegian Krone' => 'NOK - Coroa Norueguesa',
    'Show this column' => 'Mostrar esta coluna',
    'Hide this column' => 'Esconder esta coluna',
    'End date' => 'Data de término',
    'Users overview' => 'Visão geral dos usuários',
    'Members' => 'Membros',
    'Shared project' => 'Projeto compartilhado',
    'Project managers' => 'Gerentes de projeto',
    'Projects list' => 'Lista dos projetos',
    'End date:' => 'Data de término:',
    'Change task color when using a specific task link' => 'Mudar a cor da tarefa quando um link específico é utilizado',
    'Task link creation or modification' => 'Criação ou modificação de um link em uma tarefa',
    'Milestone' => 'Marco',
    'Reset the search/filter box' => 'Reiniciar o campo de pesquisa',
    'Documentation' => 'Documentação',
    'Author' => 'Autor',
    'Version' => 'Versão',
    'Plugins' => 'Plugins',
    'There is no plugin loaded.' => 'Não há plugins carregados.',
    'My notifications' => 'Minhas notificações',
    'Custom filters' => 'Filtros personalizados',
    'Your custom filter has been created successfully.' => 'Seu filtro personalizado foi criado com sucesso.',
    'Unable to create your custom filter.' => 'Não foi possível criar seu filtro personalizado.',
    'Custom filter removed successfully.' => 'Filtro personalizado removido com sucesso.',
    'Unable to remove this custom filter.' => 'Não foi possível remover este filtro personalizado.',
    'Edit custom filter' => 'Editar filtro personalizado',
    'Your custom filter has been updated successfully.' => 'Seu filtro personalizado foi atualizado com sucesso.',
    'Unable to update custom filter.' => 'Não foi possível atualizar o filtro personalizado.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Novo anexo na tarefa #%d: %s',
    'New comment on task #%d' => 'Novo comentário na tarefa #%d',
    'Comment updated on task #%d' => 'Comentário atualizado na tarefa #%d',
    'New subtask on task #%d' => 'Nova subtarefa na tarefa #%d',
    'Subtask updated on task #%d' => 'Subtarefa atualizada na tarefa #%d',
    'New task #%d: %s' => 'Nova tarefa #%d: %s',
    'Task updated #%d' => 'Tarefa #%d atualizada',
    'Task #%d closed' => 'Tarefa #%d finalizada',
    'Task #%d opened' => 'Tarefa #%d aberta',
    'Column changed for task #%d' => 'Coluna alterada para a tarefa #%d',
    'New position for task #%d' => 'Nova posição para a tarefa #%d',
    'Swimlane changed for task #%d' => 'Raia alterada para a tarefa #%d',
    'Assignee changed on task #%d' => 'Designação alterada na tarefa #%d',
    '%d overdue tasks' => '%d tarefas atrasadas',
    'No notification.' => 'Nenhuma notificação nova.',
    'Mark all as read' => 'Marcar todas como lidas',
    'Mark as read' => 'Marcar como lida',
    'Total number of tasks in this column across all swimlanes' => 'Número total de tarefas nesta coluna através de todas as raias',
    'Collapse swimlane' => 'Contrair raia',
    'Expand swimlane' => 'Expandir raia',
    'Add a new filter' => 'Adicionar filtro',
    'Share with all project members' => 'Compartilhar com todos os membros do projeto',
    'Shared' => 'Compartilhado',
    'Owner' => 'Líder',
    'Unread notifications' => 'Notificações não lidas',
    'Notification methods:' => 'Métodos de notificação:',
    'Unable to read your file' => 'Não foi possível ler seu arquivo',
    '%d task(s) have been imported successfully.' => '%d tarefa(s) importada(s) com sucesso.',
    'Nothing has been imported!' => 'Nada foi importado!',
    'Import users from CSV file' => 'Importar usuários a partir de arquivo CSV',
    '%d user(s) have been imported successfully.' => '%d usuário(s) importado(s) com sucesso.',
    'Comma' => 'Vírgula',
    'Semi-colon' => 'Ponto e vírgula',
    'Tab' => 'Tab',
    'Vertical bar' => 'Barra vertical',
    'Double Quote' => 'Aspas duplas',
    'Single Quote' => 'Aspas simples',
    '%s attached a file to the task #%d' => '%s anexou um arquivo à tarefa #%d',
    'There is no column or swimlane activated in your project!' => 'Não há coluna ou raia ativa em seu projeto!',
    'Append filter (instead of replacement)' => 'Adicionar filtro (em vez de substituir)',
    'Append/Replace' => 'Adicionar/Substituir',
    'Append' => 'Adicionar',
    'Replace' => 'Substituir',
    'Import' => 'Importar',
    'Change sorting' => 'alterar ordenação',
    'Tasks Importation' => 'Importação de Tarefas',
    'Delimiter' => 'Separador',
    'Enclosure' => 'Delimitador de campos',
    'CSV File' => 'Arquivo CSV',
    'Instructions' => 'Instruções',
    'Your file must use the predefined CSV format' => 'Seu arquivo deve utilizar o formato CSV pré-definido',
    'Your file must be encoded in UTF-8' => 'Seu arquivo deve estar codificado em UTF-8',
    'The first row must be the header' => 'A primeira linha deve ser o cabeçalho',
    'Duplicates are not verified for you' => 'Registros duplicados não são verificados',
    'The due date must use the ISO format: YYYY-MM-DD' => 'A data fim estimada deve utilizar o formato ISO: YYYY-MM-DD',
    'Download CSV template' => 'Baixar modelo de arquivo CSV',
    'No external integration registered.' => 'Nenhuma integração externa registrada.',
    'Duplicates are not imported' => 'Registros duplicados não são importados',
    'Usernames must be lowercase and unique' => 'Nomes de usuário devem ser únicos e em letras minúsculas',
    'Passwords will be encrypted if present' => 'Senhas serão encriptadas, se presentes',
    '%s attached a new file to the task %s' => '%s anexou um novo arquivo a tarefa %s',
    'Link type' => 'Tipo de link',
    'Assign automatically a category based on a link' => 'Atribuir automaticamente uma categoria baseada num link',
    'BAM - Konvertible Mark' => 'BAM - Mark conversível',
    'Assignee Username' => 'Usuário designado',
    'Assignee Name' => 'Nome do designado',
    'Groups' => 'Grupos',
    'Members of %s' => 'Membros do %s',
    'New group' => 'Novo grupo',
    'Group created successfully.' => 'Grupo criado com sucesso.',
    'Unable to create your group.' => 'Não foi possível de criar o seu grupo.',
    'Edit group' => 'Editar o grupo',
    'Group updated successfully.' => 'Grupo atualizado com sucesso.',
    'Unable to update your group.' => 'Não foi possível atualizar o seu grupo.',
    'Add group member to "%s"' => 'Adicionar um membro ao grupo "%s"',
    'Group member added successfully.' => 'Membro adicionado com sucesso ao o grupo.',
    'Unable to add group member.' => 'Não foi possível adicionar esse membro ao grupo.',
    'Remove user from group "%s"' => 'Remover usuário do grupo "%s"',
    'User removed successfully from this group.' => 'Usuário removido com sucesso deste grupo.',
    'Unable to remove this user from the group.' => 'Não foi possível remover este Usuário do grupo.',
    'Remove group' => 'Remover o grupo',
    'Group removed successfully.' => 'Grupo removido com sucesso.',
    'Unable to remove this group.' => 'Não foi possível remover este grupo.',
    'Project Permissions' => 'Permissões do projeto',
    'Manager' => 'Gerente',
    'Project Manager' => 'Gerente de projeto',
    'Project Member' => 'Membro de projeto',
    'Project Viewer' => 'Visualizador de projeto',
    'Your account is locked for %d minutes' => 'A sua conta está bloqueada por %d minutos',
    'Invalid captcha' => 'Captcha inválido',
    'The name must be unique' => 'O nome deve ser único',
    'View all groups' => 'Ver todos os grupos',
    'There is no user available.' => 'Não há nenhum usuário disponível',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Você realmente deseja remover o usuário "%s" do grupo "%s"?',
    'There is no group.' => 'Não há nenhum grupo.',
    'Add group member' => 'Adicionar um membro ao grupo',
    'Do you really want to remove this group: "%s"?' => 'Você realmente deseja excluir este grupo: "%s"?',
    'There is no user in this group.' => 'Não há usuários neste grupo.',
    'Permissions' => 'Permissões',
    'Allowed Users' => 'Usuários autorizados',
    'No specific user has been allowed.' => 'Nenhum usuário foi especificamente autorizado.',
    'Role' => 'Função',
    'Enter user name...' => 'Digite o nome do usuário...',
    'Allowed Groups' => 'Grupos autorizados',
    'No group has been allowed.' => 'Nenhum grupo foi especificamente autorizado.',
    'Group' => 'Grupo',
    'Group Name' => 'Nome do grupo',
    'Enter group name...' => 'Digite o nome do grupo',
    'Role:' => 'Função:',
    'Project members' => 'Membros de projeto',
    '%s mentioned you in the task #%d' => '%s mencionou você na tarefa #%d',
    '%s mentioned you in a comment on the task #%d' => '%s mencionou você num comentário da tarefa #%d',
    'You were mentioned in the task #%d' => 'Você foi mencionado na tarefa #%d',
    'You were mentioned in a comment on the task #%d' => 'Você foi mencionado num comentário da tarefa #%d',
    'Estimated hours: ' => 'Horas estimadas: ',
    'Actual hours: ' => 'Horas reais: ',
    'Hours Spent' => 'Horas gastas',
    'Hours Estimated' => 'Horas estimadas',
    'Estimated Time' => 'Tempo estimado',
    'Actual Time' => 'Tempo real',
    'Estimated vs actual time' => 'Tempo estimado vs tempo real',
    'RUB - Russian Ruble' => 'RUB - Rublo russo',
    'Assign the task to the person who does the action when the column is changed' => 'Atribuir a tarefa a pessoa que faz a ação quando a coluna é alterada',
    'Close a task in a specific column' => 'Finalizar uma tarefa em uma coluna específica',
    'Time-based One-time Password Algorithm' => 'Senha de uso único baseado no tempo',
    'Two-Factor Provider: ' => 'Provedor de autenticação a dois fatores: ',
    'Disable two-factor authentication' => 'Desativar a autenticação a dois fatores',
    'Enable two-factor authentication' => 'Ativar a autenticação a dois fatores',
    'There is no integration registered at the moment.' => 'Não há nenhuma integração registrada por enquanto.',
    'Password Reset for Kanboard' => 'Redefinir a senha para Kanboard',
    'Forgot password?' => 'Esqueceu a senha?',
    'Enable "Forget Password"' => 'Ativar a funcionalidade "Esqueceu a senha"',
    'Password Reset' => 'Redefinir a senha',
    'New password' => 'Nova senha',
    'Change Password' => 'Alterar a senha',
    'To reset your password click on this link:' => 'Para redefinir a sua senha, clique neste link:',
    'Last Password Reset' => 'Última redefinição de senha',
    'The password has never been reinitialized.' => 'A senha nunca foi redefinida.',
    'Creation' => 'Criação',
    'Expiration' => 'Expiração',
    'Password reset history' => 'Histórico da redefinição da senha',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Todas as tarefas da coluna "%s" e da raia "%s" foram finalizadas com sucesso.',
    'Do you really want to close all tasks of this column?' => 'Você realmente deseja finalizar todas as tarefas desta coluna?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d tarefa(s) da coluna "%s" e da raia "%s" serão finalizadas.',
    'Close all tasks in this column and this swimlane' => 'Finalizar todas as tarefas desta coluna',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Nenhum plugin registrou método de notificação de projeto. Você ainda pode definir notificações individuais em seu perfil de usuário.',
    'My dashboard' => 'Meu Painel de Controle',
    'My profile' => 'Meu perfil',
    'Project owner: ' => 'Líder do projeto: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'O identificador do projeto é opcional e deve ser alfanumérico, por exemplo MEUPROJETO.',
    'Project owner' => 'Líder do projeto',
    'Personal projects do not have users and groups management.' => 'Projetos pessoais não têm gestão de usuários e grupos.',
    'There is no project member.' => 'Não há nenhum membro do projeto.',
    'Priority' => 'Prioridade',
    'Task priority' => 'Prioridade das tarefas',
    'General' => 'Geral',
    'Dates' => 'Datas',
    'Default priority' => 'Prioridade padrão',
    'Lowest priority' => 'Prioridade baixa',
    'Highest priority' => 'Prioridade alta',
    'Close a task when there is no activity' => 'Finalizar uma tarefa sem atividade',
    'Duration in days' => 'Duração em dias',
    'Send email when there is no activity on a task' => 'Enviar um e-mail quando não há nenhuma atividade em uma tarefa',
    'Unable to fetch link information.' => 'Não foi possível obter informações sobre o link.',
    'Daily background job for tasks' => 'Tarefa agendada diariamente para as tarefas',
    'Auto' => 'Auto',
    'Related' => 'Relacionado',
    'Attachment' => 'Anexo',
    'Web Link' => 'Link web',
    'External links' => 'Links externos',
    'Add external link' => 'Adicionar um link externo',
    'Type' => 'Tipo',
    'Dependency' => 'Dependência',
    'Add internal link' => 'Adicionar um link interno',
    'Add a new external link' => 'Adicionar um novo link externo',
    'Edit external link' => 'Editar um link externo',
    'External link' => 'Link externo',
    'Copy and paste your link here...' => 'Copie e cole o link aqui...',
    'URL' => 'URL',
    'Internal links' => 'Link interno',
    'Assign to me' => 'Atribuir-me',
    'Me' => 'Eu',
    'Do not duplicate anything' => 'Não duplique nada',
    'Projects management' => 'Gestão de projetos',
    'Users management' => 'Gestão dos usuários',
    'Groups management' => 'Gestão dos grupos',
    'Create from another project' => 'Criar a partir de outro projeto',
    'open' => 'aberto',
    'closed' => 'finalizado',
    'Priority:' => 'Prioridade:',
    'Reference:' => 'Referência:',
    'Complexity:' => 'Complexidade:',
    'Swimlane:' => 'Raia:',
    'Column:' => 'Coluna:',
    'Position:' => 'Posição:',
    'Creator:' => 'Criador:',
    'Time estimated:' => 'Tempo estimado:',
    '%s hours' => '%s horas',
    'Time spent:' => 'Tempo gasto:',
    'Created:' => 'Criado:',
    'Modified:' => 'Modificado:',
    'Completed:' => 'Finalizado:',
    'Started:' => 'Começado:',
    'Moved:' => 'Movido:',
    'Task #%d' => 'Tarefa #%d',
    'Time format' => 'Formato da hora',
    'Start date: ' => 'Data de início: ',
    'End date: ' => 'Data final: ',
    'New due date: ' => 'Nova data fim estimada: ',
    'Start date changed: ' => 'Data de início alterada: ',
    'Disable personal projects' => 'Desativar projetos pessoais',
    'Do you really want to remove this custom filter: "%s"?' => 'Você realmente quer remover este filtro personalizado: "%s"?',
    'Remove a custom filter' => 'Remover um filtro personalizado',
    'User activated successfully.' => 'Usuário ativado com sucesso.',
    'Unable to enable this user.' => 'Impossível de ativar esse usuário.',
    'User disabled successfully.' => 'Usuário desactivado com sucesso.',
    'Unable to disable this user.' => 'Impossível de desativar esse usuário.',
    'All files have been uploaded successfully.' => 'Todos os arquivos foram enviados com sucesso.',
    'The maximum allowed file size is %sB.' => 'O tamanho máximo dos arquivos é %sB.',
    'Drag and drop your files here' => 'Arraste e solte os arquivos aqui',
    'choose files' => 'selecione os arquivos',
    'View profile' => 'Ver o perfil',
    'Two Factor' => 'Dois fatores',
    'Disable user' => 'Desativar o usuário',
    'Do you really want to disable this user: "%s"?' => 'Você realmente quer desativar este usuário: "%s"?',
    'Enable user' => 'Ativar um usuário',
    'Do you really want to enable this user: "%s"?' => 'Você realmente quer ativar este usuário: "%s"?',
    'Download' => 'Baixar',
    'Uploaded: %s' => 'Enviado: %s',
    'Size: %s' => 'Tamanho: %s',
    'Uploaded by %s' => 'Enviado por %s',
    'Filename' => 'Nome do arquivo',
    'Size' => 'Tamanho',
    'Column created successfully.' => 'A coluna criada com sucesso.',
    'Another column with the same name exists in the project' => 'Uma outra coluna com o mesmo nome já existe no projeto',
    'Default filters' => 'Filtros padrão',
    'Your board doesn\'t have any columns!' => 'O seu quadro não tem nenhuma coluna',
    'Change column position' => 'Alterar a posição da coluna',
    'Switch to the project overview' => 'Mudar para a vista geral do projeto',
    'User filters' => 'Filtros dos usuários',
    'Category filters' => 'Filtros das categorias',
    'Upload a file' => 'Enviar um arquivo',
    'View file' => 'Ver arquivo',
    'Last activity' => 'Últimas atividades',
    'Change subtask position' => 'Alterar a posição da subtarefa',
    'This value must be greater than %d' => 'Este valor deve ser maior que %d',
    'Another swimlane with the same name exists in the project' => 'Outra raia existe com o mesmo nome no projeto',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Exemplo: https://exemplo.kanboard.org/ (usado para gerar URLs absolutos)',
    'Actions duplicated successfully.' => 'Ações duplicadas com sucesso.',
    'Unable to duplicate actions.' => 'Não foi possível duplicar as ações.',
    'Add a new action' => 'Adicionar uma nova ação',
    'Import from another project' => 'Importar a partir de outro projeto',
    'There is no action at the moment.' => 'Não há nenhuma ação atualmente.',
    'Import actions from another project' => 'Importar ações a partir de outro projeto',
    'There is no available project.' => 'Não há projetos disponíveis.',
    'Local File' => 'Arquivo local',
    'Configuration' => 'Configuração',
    'PHP version:' => 'Versão do PHP:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Versão do sistema operacional:',
    'Database version:' => 'Versão do banco de dados:',
    'Browser:' => 'Browser:',
    'Task view' => 'Vista detalhada de uma tarefa',
    'Edit task' => 'Editar a tarefa',
    'Edit description' => 'Editar a descrição',
    'New internal link' => 'Novo link interno',
    'Display list of keyboard shortcuts' => 'Ver a lista dos atalhos de teclado',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Enviar a minha imagem de avatar',
    'Remove my image' => 'Remover a minha imagem',
    'The OAuth2 state parameter is invalid' => 'O parâmetro "state" de OAuth2 não é válido',
    'User not found.' => 'Usuário não encontrado.',
    'Search in activity stream' => 'Procurar no fluxo de atividade',
    'My activities' => 'Minhas atividades',
    'Activity until yesterday' => 'Atividade até ontem',
    'Activity until today' => 'Atividade até hoje',
    'Search by creator: ' => 'Pesquisar por criador: ',
    'Search by creation date: ' => 'Pesquisar por data de criação: ',
    'Search by task status: ' => 'Pesquisar por estado da tarefa: ',
    'Search by task title: ' => 'Pesquisar por título da tarefa: ',
    'Activity stream search' => 'Pesquisa do fluxo de atividade',
    'Projects where "%s" is manager' => 'Projetos onde "%s" é gestor',
    'Projects where "%s" is member' => 'Projetos onde "%s" é membro',
    'Open tasks assigned to "%s"' => 'Tarefas abertas atribuídas a "%s"',
    'Closed tasks assigned to "%s"' => 'Tarefas fechadas atribuídas a "%s"',
    'Assign automatically a color based on a priority' => 'Atribuir automaticamente uma cor de acordo com a prioridade',
    'Overdue tasks for the project(s) "%s"' => 'Tarefas em atraso para o(s) projeto(s) "%s"',
    'Upload files' => 'Enviar arquivos',
    'Installed Plugins' => 'Plugins Instalados',
    'Plugin Directory' => 'Pasta de Plugins',
    'Plugin installed successfully.' => 'Plugin instalado com sucesso.',
    'Plugin updated successfully.' => 'Plugin atualizado com sucesso.',
    'Plugin removed successfully.' => 'Plugin removido com sucesso.',
    'Subtask converted to task successfully.' => 'Sub-tarefa convertida para tarefa com sucesso.',
    'Unable to convert the subtask.' => 'Não foi possível converter a subtarefa.',
    'Unable to extract plugin archive.' => 'Não foi possível extrair o arquivo do plugin.',
    'Plugin not found.' => 'Plugin não encontrado.',
    'You don\'t have the permission to remove this plugin.' => 'Você não tem permissão para remover este plugin.',
    'Unable to download plugin archive.' => 'Não foi possível transferir o arquivo do plugin.',
    'Unable to write temporary file for plugin.' => 'Não foi possível escrever o arquivo temporário para o plugin.',
    'Unable to open plugin archive.' => 'Não foi possível abrir o arquivo do plugin.',
    'There is no file in the plugin archive.' => 'Ficheiro não encontrado dentro do arquivo do plugin.',
    'Create tasks in bulk' => 'Criar tarefas em massa',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Este Kanboard não está configurado para instalar plugins através da interface de usuário.',
    'There is no plugin available.' => 'Não existe nenhum plugin instalado.',
    'Install' => 'Instalar',
    'Update' => 'Atualizar',
    'Up to date' => 'Atualizado',
    'Not available' => 'Não disponível',
    'Remove plugin' => 'Remover plugin',
    'Do you really want to remove this plugin: "%s"?' => 'Tem a certeza que quer remover este plugin: "%s"?',
    'Uninstall' => 'Desinstalar',
    'Listing' => 'Listando',
    'Metadata' => 'Metadata',
    'Manage projects' => 'Gerir projetos',
    'Convert to task' => 'Converter para tarefa',
    'Convert sub-task to task' => 'Converter subtarefa para tarefa',
    'Do you really want to convert this sub-task to a task?' => 'Tem a certeza que pretende converter esta subtarefa para tarefa?',
    'My task title' => 'Título da minha tarefa',
    'Enter one task by line.' => 'Escreva uma tarefa por linha.',
    'Number of failed login:' => 'Número de logins falhados:',
    'Account locked until:' => 'Conta bloqueada até:',
    'Email settings' => 'Configurações de e-mail',
    'Email sender address' => 'Endereço de envio de e-mail',
    'Email transport' => 'Transportador de e-mail',
    'Webhook token' => 'Token do Webhook',
    'Project tags management' => 'Gestão de etiquetas do Projeto',
    'Tag created successfully.' => 'Etiqueta criada com sucesso.',
    'Unable to create this tag.' => 'Não foi possível criar esta etiqueta.',
    'Tag updated successfully.' => 'Etiqueta atualizada com sucesso.',
    'Unable to update this tag.' => 'Não foi possível atualizar esta etiqueta.',
    'Tag removed successfully.' => 'Etiqueta removida com sucesso.',
    'Unable to remove this tag.' => 'Não foi possível remover esta etiqueta.',
    'Global tags management' => 'Gestão de etiquetas globais',
    'Tags' => 'Etiquetas',
    'Tags management' => 'Gestão de etiquetas',
    'Add new tag' => 'Adicionar etiqueta nova',
    'Edit a tag' => 'Editar a etiqueta',
    'Project tags' => 'Etiquetas do Projeto',
    'There is no specific tag for this project at the moment.' => 'Atualmente não existe nenhuma etiqueta para este projeto.',
    'Tag' => 'Etiqueta',
    'Remove a tag' => 'Remover etiqueta',
    'Do you really want to remove this tag: "%s"?' => 'Tem certeza que pretende remover esta etiqueta: "%s"?',
    'Global tags' => 'Etiquetas globais',
    'There is no global tag at the moment.' => 'Atualmente não existe nenhuma etiqueta global.',
    'This field cannot be empty' => 'Este campo não pode ficar vazio',
    'Close a task when there is no activity in a specific column' => 'Fechar a tarefa quando não houver atividade numa coluna especifica',
    '%s removed a subtask for the task #%d' => '%s removeu uma subtarefa da tarefa #%d',
    '%s removed a comment on the task #%d' => '%s removeu um comentário da tarefa #%d ',
    'Comment removed on task #%d' => 'Comentário removido da tarefa #%d',
    'Subtask removed on task #%d' => 'Sub-tarefa removida da tarefa #%d',
    'Hide tasks in this column in the dashboard' => 'Esconder tarefas desta coluna no Painel de Controle',
    '%s removed a comment on the task %s' => '%s removeu um comentário da tarefa %s',
    '%s removed a subtask for the task %s' => '%s removeu uma subtarefa da tarefa %s',
    'Comment removed' => 'Comentário removido',
    'Subtask removed' => 'Sub-tarefa removida',
    '%s set a new internal link for the task #%d' => '%s definiu uma nova ligação interna para a tarefa #%d',
    '%s removed an internal link for the task #%d' => '%s removeu uma ligação interna da tarefa #%d',
    'A new internal link for the task #%d has been defined' => 'Uma nova ligação para a tarefa #%d foi definida',
    'Internal link removed for the task #%d' => 'Ligação interna removida da tarefa #%d',
    '%s set a new internal link for the task %s' => '%s definiu uma nova ligação interna para a tarefa %s',
    '%s removed an internal link for the task %s' => '%s removeu uma ligação interna da tarefa %s',
    'Automatically set the due date on task creation' => 'Definir data de vencimento automaticamente ao criar uma tarefa',
    'Move the task to another column when closed' => 'Mover a tarefa para outra coluna quando fechada',
    'Move the task to another column when not moved during a given period' => 'Mover a tarefa para outra coluna quando não movida dentro de determinado período',
    'Dashboard for %s' => 'Painel de Controle de %s',
    'Tasks overview for %s' => 'Visão geral das tarefas de %s',
    'Subtasks overview for %s' => 'Visão geral das subtarefas de %s',
    'Projects overview for %s' => 'Visão geral dos projetos de %s',
    'Activity stream for %s' => 'Fluxo de atividade de %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Atribuir uma cor quando a tarefa for movida para uma raia especifica',
    'Assign a priority when the task is moved to a specific swimlane' => 'Atribuir uma prioridade quando a tarefa for movida para uma raia especifica',
    'User unlocked successfully.' => 'Usuário desbloqueado com sucesso.',
    'Unable to unlock the user.' => 'Não foi possível desbloquear o usuário.',
    'Move a task to another swimlane' => 'Mover a tarefa para outra raia',
    'Creator Name' => 'Nome do Criador',
    'Time spent and estimated' => 'Tempo gasto e estimado',
    'Move position' => 'Mover posição',
    'Move task to another position on the board' => 'Mover tarefa para outra posição no quadro',
    'Insert before this task' => 'Inserir antes desta tarefa',
    'Insert after this task' => 'Inserir depois desta tarefa',
    'Unlock this user' => 'Desbloquear este usuário',
    'Custom Project Roles' => 'Funções Personalizadas do Projeto',
    'Add a new custom role' => 'Adicionar uma nova função personalizada',
    'Restrictions for the role "%s"' => 'Restrições para a função: "%s"',
    'Add a new project restriction' => 'Adicionar uma nova restrição de Projeto',
    'Add a new drag and drop restriction' => 'Adicionar uma nova restrição de arrastar e soltar',
    'Add a new column restriction' => 'Adicionar uma nova restrição de colunas',
    'Edit this role' => 'Editar esta função',
    'Remove this role' => 'Remover esta função',
    'There is no restriction for this role.' => 'Não existem restrições para esta função.',
    'Only moving task between those columns is permitted' => 'Só é permitido mover a tarefa entre as seguintes colunas',
    'Close a task in a specific column when not moved during a given period' => 'Fecha a tarefa numa coluna especifica quando não é movimentada durante um dado período',
    'Edit columns' => 'Editar colunas',
    'The column restriction has been created successfully.' => 'A restrição de coluna foi criada com sucesso.',
    'Unable to create this column restriction.' => 'Não foi possível criar esta restrição de coluna.',
    'Column restriction removed successfully.' => 'Restrição de coluna removida com sucesso.',
    'Unable to remove this restriction.' => 'Não foi possível remover esta restrição.',
    'Your custom project role has been created successfully.' => 'A sua função de projeto personalizada foi criada com sucesso.',
    'Unable to create custom project role.' => 'Não foi possível criar a função de projeto personalizada.',
    'Your custom project role has been updated successfully.' => 'A sua função de projeto personalizada foi atualizada com sucesso.',
    'Unable to update custom project role.' => 'Não foi possível atualizar a função de projeto personalizada.',
    'Custom project role removed successfully.' => 'Função de projeto removida com sucesso.',
    'Unable to remove this project role.' => 'Não foi possível remover esta função de projeto.',
    'The project restriction has been created successfully.' => 'A restrição de projeto foi criada com sucesso.',
    'Unable to create this project restriction.' => 'Não foi possível remover esta restrição de projeto.',
    'Project restriction removed successfully.' => 'Restrição de projeto removida com sucesso.',
    'You cannot create tasks in this column.' => 'Não pode criar tarefas nesta coluna.',
    'Task creation is permitted for this column' => 'A criação de tarefas é permitida nesta coluna',
    'Closing or opening a task is permitted for this column' => 'Fechar ou abrir tarefas é permitido nesta coluna',
    'Task creation is blocked for this column' => 'A criação de tarefas está bloqueada nesta coluna',
    'Closing or opening a task is blocked for this column' => 'Fechar ou abrir tarefas está bloqueado nesta coluna',
    'Task creation is not permitted' => 'A criação de tarefas não é permitida',
    'Closing or opening a task is not permitted' => 'Fechar ou abrir tarefas não é permitido',
    'New drag and drop restriction for the role "%s"' => 'Nova restrição de arrastar e soltar para a função: "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Pessoas pertecentes a esta função poderão mover apenas tarefas entre essas colunas de origem e de destino.',
    'Remove a column restriction' => 'Remover a restrição de coluna',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Tem a certeza que quer remover a restrição de coluna: "%s" para "%s"?',
    'New column restriction for the role "%s"' => 'Nova restrição de coluna para a função: "%s"',
    'Rule' => 'Regra',
    'Do you really want to remove this column restriction?' => 'Tem a certeza que quer remover esta restrição de coluna?',
    'Custom roles' => 'Funções personalizadas',
    'New custom project role' => 'Nova função de projeto personalizada',
    'Edit custom project role' => 'Editar função de projeto personalizada',
    'Remove a custom role' => 'Remover função de projeto personalizada',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Tem certeza que quer remover esta função personalizada: "%s"? Todas as pessoas atribuídas a esta função ficarão membros do projeto.',
    'There is no custom role for this project.' => 'Não existem funções personalizadas para este projeto',
    'New project restriction for the role "%s"' => 'Nova restrição de projeto para a função: "%s"',
    'Restriction' => 'Restrição',
    'Remove a project restriction' => 'Remover uma restrição de projeto',
    'Do you really want to remove this project restriction: "%s"?' => 'Tem a certeza que quer remover a restrição de projeto: "%s"?',
    'Duplicate to multiple projects' => 'Duplicar para vários projetos',
    'This field is required' => 'Este campo é obrigatório',
    'Moving a task is not permitted' => 'Mover uma tarefa não é permitido',
    'This value must be in the range %d to %d' => 'Este valor precisa estar no intervalo %d até %d',
    'You are not allowed to move this task.' => 'Você não está autorizado a mover esta tarefa.',
    'API User Access' => 'Acesso à API do usuário',
    'Preview' => 'Pré-visualizar',
    'Write' => 'Escrever',
    'Write your text in Markdown' => 'Escreva seu texto em Markdown',
    'No personal API access token registered.' => 'Nenhum token de acesso pessoal à API registrado.',
    'Your personal API access token is "%s"' => 'Seu token de acesso pessoal à API é "%s"',
    'Remove your token' => 'Remover seu token',
    'Generate a new token' => 'Gerar um novo token',
    'Showing %d-%d of %d' => 'Mostrando %d-%d de %d',
    'Outgoing Emails' => 'E-mails de saída',
    'Add or change currency rate' => 'Adicionar ou alterar taxa de câmbio',
    'Reference currency: %s' => 'Câmbio de referência: %s',
    'Add custom filters' => 'Adicionar filtros personalizados',
    'Export' => 'Exportar',
    'Add link label' => 'Adicionar rótulo de link',
    'Incompatible Plugins' => 'Plugin incompatível',
    'Compatibility' => 'Compatibilidade',
    'Permissions and ownership' => 'Permissões e propriedade',
    'Priorities' => 'Propriedades',
    'Close this window' => 'Fechar esta janela',
    'Unable to upload this file.' => 'Não é possível carregar este arquivo',
    'Import tasks' => 'Importar tarefas',
    'Choose a project' => 'Escolher um projeto',
    'Profile' => 'Perfil',
    'Application role' => 'Regra de aplicação',
    '%d invitations were sent.' => '%d convites foram enviados.',
    '%d invitation was sent.' => '%d convite foi enviado.',
    'Unable to create this user.' => 'Não foi possível criar este usuário.',
    'Kanboard Invitation' => 'Convite do Kanboard',
    'Visible on dashboard' => 'Visível no painel de controle',
    'Created at:' => 'Criado em:',
    'Updated at:' => 'Atualizado em:',
    'There is no custom filter.' => 'Não existe nenhum filtro personalizado.',
    'New User' => 'Novo Usuário',
    'Authentication' => 'Autenticação',
    'If checked, this user will use a third-party system for authentication.' => 'Se marcado, este usuário usará um sistema de autenticação de terceiros.',
    'The password is necessary only for local users.' => 'A senha é necessária somente para usuários locais.',
    'You have been invited to register on Kanboard.' => 'Você foi convidado a se registrar no Kanboard',
    'Click here to join your team' => 'Clique aqui para se unir ao seu time',
    'Invite people' => 'Convidar pessoas',
    'Emails' => 'E-mails',
    'Enter one email address by line.' => 'Digite um e-mail por linha. ',
    'Add these people to this project' => 'Adicionar estas pessoas para este projeto',
    'Add this person to this project' => 'Adicionar esta pessoa para este projeto',
    'Sign-up' => 'Inscrever-se',
    'Credentials' => 'Credenciais',
    'New user' => 'Novo usuário',
    'This username is already taken' => 'Este nome de usuário já está em uso',
    'Your profile must have a valid email address.' => 'Seu perfil precisa ter um endereço de e-mail válido.',
    'TRL - Turkish Lira' => 'TRL - Lira turca',
    'The project email is optional and could be used by several plugins.' => 'O e-mail do projeto é opcional e pode ser usado por diversos plugins.',
    'The project email must be unique across all projects' => 'O e-mail do projeto deve ser exclusivo em relação aos demais os projetos',
    'The email configuration has been disabled by the administrator.' => 'A configuração de e-mail foi desabilitada pelo administrador.',
    'Close this project' => 'Fechar este projeto',
    'Open this project' => 'Abrir este projeto',
    'Close a project' => 'Fechar um projeto',
    'Do you really want to close this project: "%s"?' => 'Deseja realmente fechar este projeto: "%s"?',
    'Reopen a project' => 'Reabrir um projeto',
    'Do you really want to reopen this project: "%s"?' => 'Deseja realmente reabrir este projeto: "%s"?',
    'This project is open' => 'Este projeto está aberto',
    'This project is closed' => 'Este projeto está fechado',
    'Unable to upload files, check the permissions of your data folder.' => 'Incapaz de enviar arquivos. Verifique as permissões da sua pasta de dados.',
    'Another category with the same name exists in this project' => 'Outra categoria com o mesmo nome existe neste projeto',
    'Comment sent by email successfully.' => 'Comentário enviado por e-mail com sucesso.',
    'Sent by email to "%s" (%s)' => 'Enviar por e-mail para "%s" (%s)',
    'Unable to read uploaded file.' => 'Incapaz de ler arquivos enviados.',
    'Database uploaded successfully.' => 'Base de dados enviado com sucesso.',
    'Task sent by email successfully.' => 'Tarefa enviada por e-mail com sucesso.',
    'There is no category in this project.' => 'Não há categoria neste projeto.',
    'Send by email' => 'Enviar por e-mail',
    'Create and send a comment by email' => 'Criar e enviar um comentário por e-mail',
    'Subject' => 'Assunto',
    'Upload the database' => 'Enviar uma base de dados',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Você pode enviar uma base de dados Sqlite baixada anteriormente (formato Gzip).',
    'Database file' => 'Arquivo de base de dados',
    'Upload' => 'Enviar',
    'Your project must have at least one active swimlane.' => 'Seu projeto precisa ter pelo menos uma raia ativa.',
    'Project: %s' => 'Projeto: %s',
    'Automatic action not found: "%s"' => 'Ação automática não encontrada: "%s"',
    '%d projects' => '%d projetos',
    '%d project' => '%d projeto',
    'There is no project.' => 'Não há projeto.',
    'Sort' => 'Ordenar',
    'Project ID' => 'ID do projeto',
    'Project name' => 'Nome do projeto',
    'Public' => 'Público',
    'Personal' => 'Privado',
    '%d tasks' => '%d tarefas',
    '%d task' => '%d tarefa',
    'Task ID' => 'ID da tarefa',
    'Assign automatically a color when due date is expired' => 'Atribuir automaticamente uma cor quando a data de vencimento está expirada',
    'Total score in this column across all swimlanes' => 'Pontuação total nesta coluna através de todas as raias',
    'HRK - Kuna' => 'HRK - Kuna',
    'ARS - Argentine Peso' => 'ARS - Peso argentino',
    'COP - Colombian Peso' => 'COP - Peso colombiano',
    '%d groups' => '%d grupos',
    '%d group' => '%d grupo',
    'Group ID' => 'ID do grupo',
    'External ID' => 'ID externo',
    '%d users' => '%d usuários',
    '%d user' => '%d usuário',
    'Hide subtasks' => 'Esconder subtarefa',
    'Show subtasks' => 'Mostrar subtarefa',
    'Authentication Parameters' => 'Parâmetros de autenticação',
    'API Access' => 'Acesso à API',
    'No users found.' => 'Usuários não encontrados.',
    'User ID' => 'ID do usuário',
    'Notifications are activated' => 'As notificações estão ativadas',
    'Notifications are disabled' => 'As notificações estão desativadas',
    'User disabled' => 'Usuário desativado',
    '%d notifications' => '%d notificações',
    '%d notification' => '%d notificação',
    'There is no external integration installed.' => 'Não existe integração externa instalada.',
    'You are not allowed to update tasks assigned to someone else.' => 'Você não está autorizado a atualizar tarefas designadas para outros.',
    'You are not allowed to change the assignee.' => 'Você não está autorizado a mudar a designação.',
    'Task suppression is not permitted' => 'Supressão de tarefa não é permitida',
    'Changing assignee is not permitted' => 'Mudança de designação não é permitida',
    'Update only assigned tasks is permitted' => 'Atualizar somente tarefas designadas é permitida',
    'Only for tasks assigned to the current user' => 'Somente para tarefas designadas para o usuário atual',
    'My projects' => 'Meus projetos',
    'You are not a member of any project.' => 'Você não é membro de nenhum projeto.',
    'My subtasks' => 'Minhas subtarefas',
    '%d subtasks' => '%d subtarefas',
    '%d subtask' => '%d subtarefa',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Somente movimentação de tarefas entre aquelas colunas são permitidas para tarefas designadas para o usuário atual',
    '[DUPLICATE]' => '[DUPLICADO]',
    'DKK - Danish Krona' => 'DKK - Coroa Dinamarquesa',
    'Remove user from group' => 'Remover usuário do grupo',
    'Assign the task to its creator' => 'Atribuir a tarefa ao seu criador',
    'This task was sent by email to "%s" with subject "%s".' => 'Esta tarefa foi enviada por e-mail para "%s" com o assunto "%s".',
    'Predefined Email Subjects' => 'Assuntos predefinidos de e-mail',
    'Write one subject by line.' => 'Escreva um assunto por linha.',
    'Create another link' => 'Criar outro link',
    'BRL - Brazilian Real' => 'BRL - Real Brasileiro',
    'Add a new Kanboard task' => 'Adicionar uma nova tarefa do Kanboard',
    'Subtask not started' => 'Subtarefa não iniciada',
    'Subtask currently in progress' => 'Subtarefa atualmente em progresso',
    'Subtask completed' => 'Subtarefa finalizada',
    'Subtask added successfully.' => 'Subtarefa adicionada com sucesso.',
    '%d subtasks added successfully.' => '%d subtarefas adicionadas com sucesso.',
    'Enter one subtask by line.' => 'Escreva uma subtarefa por linha.',
    'Predefined Contents' => 'Conteúdos predefinidos',
    'Predefined contents' => 'Conteúdos predefinidos',
    'Predefined Task Description' => 'Descrição de tarefa pré-definida',
    'Do you really want to remove this template? "%s"' => 'Deseja realmente remover este modelo? "%s"',
    'Add predefined task description' => 'Adicionar descrição de tarefa pré-definida',
    'Predefined Task Descriptions' => 'Descrições de tarefas pré-definidas',
    'Template created successfully.' => 'Modelo criado com sucesso.',
    'Unable to create this template.' => 'Incapaz de criar este modelo.',
    'Template updated successfully.' => 'Modelo atualizado com sucesso.',
    'Unable to update this template.' => 'Incapaz de atualizar este modelo.',
    'Template removed successfully.' => 'Modelo removido com sucesso.',
    'Unable to remove this template.' => 'Incapaz de remover este modelo.',
    'Template for the task description' => 'Modelo para a descrição de tarefa',
    'The start date is greater than the end date' => 'A data de início é maior que a data final',
    'Tags must be separated by a comma' => 'As tags precisam ser separadas por vírgula',
    'Only the task title is required' => 'Somente o título da tarefa é requerida',
    'Creator Username' => 'Usuário criador',
    'Color Name' => 'Nome da cor',
    'Column Name' => 'Nome da coluna',
    'Swimlane Name' => 'Nome da raia',
    'Time Estimated' => 'Tempo estimado',
    'Time Spent' => 'Tempo gasto',
    'External Link' => 'Link externo',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Essa funcionalidade habilita o alimentador de iCal, RSS e visualização pública do quadro.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Parar o temporizador de todas as subtarefas quando mover a tarefa para outra coluna',
    'Subtask Title' => 'Título da subtarefa',
    'Add a subtask and activate the timer when moving a task to another column' => 'Adicionar uma subtarefa e ativar o temporizador quando mover a tarefa para outra coluna',
    'days' => 'dias',
    'minutes' => 'minutos',
    'seconds' => 'segundos',
    'Assign automatically a color when preset start date is reached' => 'Atribuir automaticamente uma cor quando a data de início for atingida',
    'Move the task to another column once a predefined start date is reached' => 'Mover a tarefa para outra coluna quando a data de início for atingida',
    'This task is now linked to the task %s with the relation "%s"' => 'Esta tarefa agora está vinculada à tarefa %s com a relação "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'O vínculo com a relação "%s" para a tarefa %s foi removido',
    'Custom Filter:' => 'Filtro personalizado:',
    'Unable to find this group.' => 'Incapaz de encontrar este grupo.',
    '%s moved the task #%d to the column "%s"' => '%s moveu a tarefa #%d para a coluna "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s moveu a tarefa #%d para a posição %d na coluna "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s moveu a tarefa #%d para a raia "%s"',
    '%sh spent' => '%sh gasto',
    '%sh estimated' => '%sh estimado',
    'Select All' => 'Selecionar todos',
    'Unselect All' => 'Desmarcar todos',
    'Apply action' => 'Aplicar ação',
    'Move selected tasks to another column or swimlane' => 'Mover tarefas selecionadas para outra coluna',
    'Edit tasks in bulk' => 'Editar tarefas em massa',
    'Choose the properties that you would like to change for the selected tasks.' => 'Escolher as propriedades que deseja mudar para as tarefas selecionadas.',
    'Configure this project' => 'Configurar este projeto',
    'Start now' => 'Iniciar agora',
    '%s removed a file from the task #%d' => '%s removeu um arquivo da tarefa #%d',
    'Attachment removed from task #%d: %s' => 'Anexo removido da tarefa #%d: %s',
    'No color' => 'Nenhuma cor',
    'Attachment removed "%s"' => 'Anexo removido "%s"',
    '%s removed a file from the task %s' => '%s removeu um arquivo da tarefa %s',
    'Move the task to another swimlane when assigned to a user' => 'Mover a tarefa para uma outra raia quando esta está atribuída a um usuário',
    'Destination swimlane' => 'Raia de destino',
    'Assign a category when the task is moved to a specific swimlane' => 'Atribuir uma categoria quando a tarefa for movida para uma raia específica',
    'Move the task to another swimlane when the category is changed' => 'Mover a tarefa para outra raia quando a categoria é alterada',
    'Reorder this column by priority (ASC)' => 'Reordenar esta coluna por prioridade (crescente)',
    'Reorder this column by priority (DESC)' => 'Reordenar esta coluna por prioridade (decrescente)',
    'Reorder this column by assignee and priority (ASC)' => 'Reordenar esta coluna por designado e prioridade (crescente)',
    'Reorder this column by assignee and priority (DESC)' => 'Reordenar esta coluna por designado e prioridade (decrescente)',
    'Reorder this column by assignee (A-Z)' => 'Reordenar esta coluna por designado (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Reordenar esta coluna por designado (Z-A)',
    'Reorder this column by due date (ASC)' => 'Reordenar esta coluna por data fim estimada (crescente)',
    'Reorder this column by due date (DESC)' => 'Reordenar esta coluna por data fim estimada (decrescente)',
    'Reorder this column by id (ASC)' => 'Reordenar esta coluna por id (ASC)',
    'Reorder this column by id (DESC)' => 'Reordenar esta coluna por id (DESC)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s moveu a tarefa #%d "%s" para o projeto "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Tarefa #%d "%s" foi movida para o projeto "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Mover a tarefa para outra coluna quando a data fim estimada for menor que uma quantidade de dias',
    'Automatically update the start date when the task is moved away from a specific column' => 'Atualizar automaticamente a data de início quando a tarefa sair de determinada coluna',
    'HTTP Client:' => 'Cliente HTTP:',
    'Assigned' => 'Atribuído',
    'Task limits apply to each swimlane individually' => 'Limites de tarefas aplicam-se a cada raia individualmente',
    'Column task limits apply to each swimlane individually' => 'Limites de tarefas da coluna aplicam-se a cada raia individualmente',
    'Column task limits are applied to each swimlane individually' => 'Limites de tarefas da coluna estão aplicados a cada raia individualmente',
    'Column task limits are applied across swimlanes' => 'Limites de tarefas da coluna estão aplicados por todas as raias',
    'Task limit: ' => 'Limite de tarefas:',
    'Change to global tag' => 'Transformar em etiqueta global',
    'Do you really want to make the tag "%s" global?' => 'Você realmente deseja transformar a etiqueta "%s" em etiqueta global?',
    'Enable global tags for this project' => 'Habilitar etiquetas globais para este projeto',
    'Group membership(s):' => 'Filiação a grupo(s):',
    '%s is a member of the following group(s): %s' => '%s é um membro do(s) seguinte(s) grupo(s): %s',
    '%d/%d group(s) shown' => '%d/%d grupo(s) exibidos',
    'Subtask creation or modification' => 'Criação ou edição de subtarefas',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Atribuir a tarefa a um usuário específico quando a tarefa for movida para uma raia especifica',
    'Comment' => 'Comentário',
    'Collapse vertically' => 'Contrair verticalmente',
    'Expand vertically' => 'Expandir verticalmente',
    'MXN - Mexican Peso' => 'MXN - Peso mexicano',
    'Estimated vs actual time per column' => 'Tempo estimado vs real por coluna',
    'HUF - Hungarian Forint' => 'HUF - Forint húngaro',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Você deve selecionar um arquivo para enviar como seu avatar!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'O arquivo enviado não é uma imagem válida! (Apenas *.gif, *.jpg, *.jpeg e *.png são permitidos!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Definir automaticamente a data de vencimento quando a tarefa for movida de uma coluna específica',
    'No other projects found.' => 'Nenhum outro projeto encontrado.',
    'Tasks copied successfully.' => 'Tarefas copiadas com sucesso.',
    'Unable to copy tasks.' => 'Não foi possível copiar as tarefas.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Tema claro',
    'Dark theme' => 'Tema escuro',
    'Automatic theme - Sync with system' => 'Tema automático - Sincronizar com o sistema',
    'Application managers or more' => 'Gerentes de aplicação ou mais',
    'Administrators' => 'Administradores',
    'Visibility:' => 'Visibilidade:',
    'Standard users' => 'Usuários padrão',
    'Visibility is required' => 'A visibilidade é obrigatória',
    'The visibility should be an app role' => 'A visibilidade deve ser um papel do aplicativo',
    'Reply' => 'Responder',
    '%s wrote: ' => '%s escreveu: ',
    'Number of visible tasks in this column and swimlane' => 'Número de tarefas visíveis nesta coluna e raia',
    'Number of tasks in this swimlane' => 'Número de tarefas nesta raia',
    'Unable to find another subtask in progress, you can close this window.' => 'Não foi possível encontrar outra subtarefa em andamento, você pode fechar esta janela.',
    'This theme is invalid' => 'Este tema é inválido',
    'This role is invalid' => 'Este papel é inválido',
    'This timezone is invalid' => 'Este fuso horário é inválido',
    'This language is invalid' => 'Este idioma é inválido',
    'This URL is invalid' => 'Esta URL é inválida',
    'Date format invalid' => 'Formato de data inválido',
    'Time format invalid' => 'Formato de hora inválido',
    'Invalid Mail transport' => 'Transporte de e-mail inválido',
    'Color invalid' => 'Cor inválida',
    'This value must be greater or equal to %d' => 'Este valor deve ser maior ou igual a %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Adicione um BOM no início do arquivo (necessário para o Microsoft Excel)',
    'Just add these tag(s)' => 'Adicione apenas estas etiquetas',
    'Remove internal link(s)' => 'Remova os links internos',
    'Import tasks from another project' => 'Importe tarefas de outro projeto',
    'Select the project to copy tasks from' => 'Selecione o projeto do qual deseja copiar tarefas',
    'The total maximum allowed attachments size is %sB.' => 'O tamanho máximo total permitido para anexos é %sB.',
    'Add attachments' => 'Adicionar anexos',
    'Task #%d "%s" is overdue' => 'Tarefa #%d "%s" está atrasada',
    'Enable notifications by default for all new users' => 'Habilitar notificações por padrão para todos os novos usuários',
    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Atribuir a tarefa ao seu criador para colunas específicas se nenhum responsável for definido manualmente',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Atribuir a tarefa ao usuário logado ao mudar de coluna para a coluna especificada se nenhum usuário estiver atribuído',
];
